"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerProviders = void 0;
const factories_1 = require("../factories");
const services_1 = require("../services");
const applicationInsightsLogger_1 = require("../services/logger/applicationInsightsLogger");
const utils_1 = require("../utils");
/**
 * Register all service providers
 */
function registerProviders() {
    const defaultAppInsightsProperties = {
        version: utils_1.PackageJson.getVersion(),
    };
    registerAgileServiceProviders();
    registerRepoServiceProviders();
    registerLoggerServiceProviders(defaultAppInsightsProperties);
    registerMetricsServiceProviders(defaultAppInsightsProperties);
}
exports.registerProviders = registerProviders;
/**
 * Register all Agile Service Providers
 */
function registerAgileServiceProviders() {
    factories_1.AgileServiceFactory.register(services_1.AgileServiceProvider.AzureDevOps, services_1.AzureDevOpsAgileService);
    factories_1.AgileServiceFactory.register(services_1.AgileServiceProvider.Jira, services_1.JiraAgileService);
    factories_1.AgileServiceFactory.register(services_1.AgileServiceProvider.GitHub, services_1.GitHubAgileService);
}
/**
 * Register all Repo Service Providers
 */
function registerRepoServiceProviders() {
    factories_1.RepoServiceFactory.register(services_1.RepoServiceProvider.GitHub, services_1.GitHubRepoService);
    factories_1.RepoServiceFactory.register(services_1.RepoServiceProvider.AzureDevOps, services_1.AzureDevOpsRepoService);
}
/**
 * Register all available loggers
 *
 * @param {Properties} defaultAppInsightsProperties Default properties for app insights clients
 */
function registerLoggerServiceProviders(defaultAppInsightsProperties) {
    const consoleLogger = new services_1.ConsoleLogger();
    factories_1.LoggerFactory.register(services_1.LoggerProvider.Console, consoleLogger);
    const compositeLoggers = [consoleLogger];
    if (utils_1.Config.isAppInsightsEnabled()) {
        const appInsightsLogger = new applicationInsightsLogger_1.ApplicationInsightsLogger(defaultAppInsightsProperties);
        factories_1.LoggerFactory.register(services_1.LoggerProvider.AppInsights, appInsightsLogger);
        compositeLoggers.push(appInsightsLogger);
    }
    factories_1.LoggerFactory.register(services_1.LoggerProvider.Composite, new services_1.CompositeLogger(compositeLoggers));
}
/**
 * Register all available metrics providers
 *
 * @param {Properties} defaultAppInsightsProperties Default properties for app insights clients
 */
function registerMetricsServiceProviders(defaultAppInsightsProperties) {
    if (utils_1.Config.isAppInsightsEnabled()) {
        const appInsightsMetrics = new services_1.ApplicationInsightsMetrics(defaultAppInsightsProperties);
        factories_1.MetricsFactory.register(services_1.MetricsProvider.AppInsights, appInsightsMetrics);
    }
}
