"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationInsightsLogger = void 0;
const applicationinsights_1 = require("applicationinsights");
const Contracts_1 = require("applicationinsights/out/Declarations/Contracts");
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
const baseLogger_1 = require("./baseLogger");
class ApplicationInsightsLogger extends baseLogger_1.BaseLogger {
    constructor(defaultProperties) {
        super(defaultProperties);
        this.debug = (message, properties) => {
            this.writeLog(Contracts_1.SeverityLevel.Verbose, message, properties);
        };
        this.log = (message, properties) => {
            this.writeLog(Contracts_1.SeverityLevel.Information, message, properties);
        };
        this.warn = (message, properties) => {
            this.writeLog(Contracts_1.SeverityLevel.Warning, message, properties);
        };
        this.error = (message, properties) => {
            this.writeLog(Contracts_1.SeverityLevel.Error, message, properties);
        };
        this.client = new applicationinsights_1.TelemetryClient(utils_1.Config.getValue(constants_1.ConfigKey.AppInsightsInstrumentationKey));
    }
    /**
     * Write log to AppInsights with specified severity level.
     *
     * @param {SeverityLevel} severity The severity at which to send the log
     * @param {string} message The log to send to AppInsights
     * @param {Properties | undefined} properties Custom properties to add - see https://github.com/Microsoft/ApplicationInsights-JS#sending-telemetry-to-the-azure-portal
     */
    writeLog(severity, message, properties) {
        /* eslint-disable prettier/prettier */
        const props = this.defaultProperties
            ? Object.assign(Object.assign({}, this.defaultProperties), properties) : properties;
        /* eslint-enable prettier/prettier */
        this.client.trackTrace({
            message,
            severity,
            properties: props,
        });
    }
}
exports.ApplicationInsightsLogger = ApplicationInsightsLogger;
